source /home/stack/stackrc
NODE_IP=$(openstack server show compute-0 -f json  | jq -r .addresses | grep -oP '[0-9.]+')

OVS_RUNNING=$(ssh -q -o StrictHostKeyChecking=no heat-admin@$NODE_IP 'sudo ovs-vsctl show' | grep ovs_version | awk -F \" {'print $2'} | awk -F "." '{print $1"."$2}')
OVS_INSTALLED=$(ssh -q -o StrictHostKeyChecking=no heat-admin@$NODE_IP 'sudo rpm --queryformat %{VERSION} -q openvswitch' | awk -F "." '{print $1"."$2}')

## change
if [[ $OVS_RUNNING != $OVS_INSTALLED ]]; then

echo "Upgraded OVS detected. Rebooting compute-0"
ssh -q -o StrictHostKeyChecking=no heat-admin@$NODE_IP 'sudo reboot'

## wait for node to go down
timeout_seconds=300
elapsed_seconds=0
while true; do
    echo "Waiting for compute-0 to go down ..."
    NODE_DOWN=$(ping -c1 $NODE_IP)
    if [ $? != 0 ]; then
        break
    fi
    sleep 3
    (( elapsed_seconds += 3 ))
    if [ $elapsed_seconds -ge $timeout_seconds ]; then
        echo "FAILURE: Node compute-0 didn't reboot"
        exit 1
    fi
done

## wait for node to get back online
timeout_seconds=300
elapsed_seconds=0
while true; do
    echo "Waiting for compute-0 to boot ..."
    NOVACOMPUTE_STATUS=$(ssh -q -o StrictHostKeyChecking=no heat-admin@$NODE_IP 'sudo docker inspect --format="{{ .State.Running }}" nova_compute')
    if [[ $NOVACOMPUTE_STATUS == 'true' ]]; then
        break
    fi
    sleep 3
    (( elapsed_seconds += 3 ))
    if [ $elapsed_seconds -ge $timeout_seconds ]; then
        echo "FAILURE: Nova compute container didn't start on compute-0"
        exit 1
    fi
done

## wait for nove compute service to be reported as up
source /home/stack/overcloudrc
timeout_seconds=300
elapsed_seconds=0
while true; do
    echo "Waiting for nova-compute service on compute-0 to go up ..."
    NOVACOMPUTE_ENABLED=$(openstack compute service list --host compute-0.localdomain -f json | jq -r -c '.[] | select(.Binary | contains("nova-compute")) | .State' | head -1)
    if [[ $NOVACOMPUTE_ENABLED == 'up' ]]; then
        break
    fi
    sleep 3
    (( elapsed_seconds += 3 ))
    if [ $elapsed_seconds -ge $timeout_seconds ]; then
        echo "FAILURE: Nova compute service didn't come up on compute-0"
        exit 1
    fi
done
fi

source /home/stack/overcloudrc
## Detect if ceph shared storage was used
STORAGE_BACKEND=$(openstack volume service list -f json | jq -r -c '.[] | select(.Binary | contains("cinder-volume")) | .Host' | sed s/hostgroup@tripleo_//)
